==> export-events-0.1.0.tgz: package/lib/readAllEvents.js <==
var request = require('request');
var async = require('async');
var fs = require('fs')

var args, evtsToIgnore, streamsToIgnore, streamUrl

var getEvents = function(url, cb) {
  request({
    headers: {
      "Accept": "application/json"
    },
    method: 'GET',
    url: url + "?embed=body",
    auth: {
      user: args.username,
      password: args.password
    }
  }, (err, response, body) => {
    if(err)
      return cb(err, null);

    if(response.statusCode !== 200)
      return cb(`StatusCode:${response.statusCode} on GET ${url}`, null)

    cb(null, body);
  });
}

function getUrlOfStartPage(streamUrl, cb) {
  getEvents(streamUrl, (err, responseString) => {
    if(err)
      throw("Failed to GET " + streamUrl);

    var response = JSON.parse(responseString);
    cb(null, getLink(response, "last").uri)
  })
}

function getLink(response, linkRelation) {
  return response.links.filter((link) => {
    return link.relation === linkRelation
  })[0];
}

function getPageOfEvents(url, handlers, onCaughtUp) {
  getEvents(url, function(err, responseString) {
    try {
      var response = JSON.parse(responseString);
      var events = response.entries.reverse();

      async.eachSeries(events, (evt, cb) => {
        handler(evt, cb)
      }, () => {
        var linkToNextPage = getLink(response, "previous")
        if(linkToNextPage) {
          getPageOfEvents(linkToNextPage.uri, handlers, onCaughtUp, getEvents);
        }else{
          onCaughtUp();
        }
      })
    } catch(err) {
      console.log("ERROR")      
      console.log(err)
    }
  });
}

var handler = (evt, cb) => {
  if(evtsToIgnore.indexOf(evt.eventType) === -1 && streamsToIgnore.indexOf(evt.streamId) === -1)
    console.log(JSON.stringify(evt))

  cb()
}

var onCaughtUp = () => {}

module.exports = function(_args) {
  args = _args
  streamUrl = `http://${args.ipaddress}:${args.port}/streams/%24all`;
  evtsToIgnore = []
  streamsToIgnore = []

  if(args.filtertypes) {
    evtsToIgnore = fs.readFileSync(args.filtertypes, 'utf8').split('\r\n').filter(evt => evt.length > 0)
    console.error("Ignoring Event Types:", evtsToIgnore)
  }

  if(args.filterstreams) {
    streamsToIgnore = fs.readFileSync(args.filterstreams, 'utf8').split('\r\n').filter(evt => evt.length > 0)
    console.error("Ignoring Stream Ids:", streamsToIgnore)
  }

  getUrlOfStartPage(streamUrl, (err, url) => {
    if(err)
      throw err

    getPageOfEvents(url, handler, onCaughtUp, getEvents)
  })
}

==> export-events-0.2.0.tgz: package/lib/readAllEvents.js <==
var request = require('request');
var async = require('async');
var fs = require('fs')

var args, evtsToIgnore, streamsToIgnore, streamUrl

var getEvents = function(url, cb) {
  request({
    headers: {
      "Accept": "application/json"
    },
    method: 'GET',
    url: url + "?embed=body",
    auth: {
      user: args.username,
      password: args.password
    }
  }, (err, response, body) => {
    if(err)
      return cb(err, null);

    if(response.statusCode !== 200)
      return cb(`StatusCode:${response.statusCode} on GET ${url}`, null)

    cb(null, body);
  });
}

function getUrlOfStartPage(streamUrl, cb) {
  getEvents(streamUrl, (err, responseString) => {
    if(err)
      throw("Failed to GET " + streamUrl);

    var response = JSON.parse(responseString);
    cb(null, getLink(response, "last").uri)
  })
}

function getLink(response, linkRelation) {
  return response.links.filter((link) => {
    return link.relation === linkRelation
  })[0];
}

function getPageOfEvents(url, handlers, onCaughtUp) {
  getEvents(url, function(err, responseString) {
    try {
      var response = JSON.parse(responseString);
      var events = response.entries.reverse();

      async.eachSeries(events, (evt, cb) => {
        handler(evt, cb)
      }, () => {
        var linkToNextPage = getLink(response, "previous")
        if(linkToNextPage) {
          getPageOfEvents(linkToNextPage.uri, handlers, onCaughtUp, getEvents);
        }else{
          onCaughtUp();
        }
      })
    } catch(err) {
      console.log("ERROR")      
      console.log(err)
    }
  });
}

var handler = (evt, cb) => {
  if(evtsToIgnore.indexOf(evt.eventType) === -1 && streamsToIgnore.indexOf(evt.streamId) === -1)
    console.log(JSON.stringify(evt))

  cb()
}

var onCaughtUp = () => {}

module.exports = function(_args) {
  args = _args
  streamUrl = `http://${args.ipaddress}:${args.port}/streams/%24all`;
  evtsToIgnore = []
  streamsToIgnore = []

  if(args.filtertypes) {
    evtsToIgnore = fs.readFileSync(args.filtertypes, 'utf8').replace(/\r\n/g,'\n').split('\n').filter(evt => evt.length > 0)
    console.error("Ignoring Event Types:", evtsToIgnore)
  }

  if(args.filterstreams) {
    streamsToIgnore = fs.readFileSync(args.filterstreams, 'utf8').replace(/\r\n/g,'\n').split('\n').filter(evt => evt.length > 0)
    console.error("Ignoring Stream Ids:", streamsToIgnore)
  }

  getUrlOfStartPage(streamUrl, (err, url) => {
    if(err)
      throw err

    getPageOfEvents(url, handler, onCaughtUp, getEvents)
  })
}
